@@ -54,19 +54,52 @@ ImportImageDlg::ImportImageDlg(QWidget *parent, const Magick::Image &originalIma
 {
     ui.setupUi(this);
 
-    ui.FlossScheme->addItems(SchemeManager::schemes());
+    m_crop = QRect(0, 0, m_originalImage.columns(), m_originalImage.rows());
+    m_originalSize = QSize(m_crop.width(), m_crop.height());
+    updateWindowTitle();
+    
+    // disable some signals whilst the dialog is setup
+    ui.FlossScheme->blockSignals(true);
+    ui.UseMaximumColors->blockSignals(true);
+    ui.MaximumColors->blockSignals(true);
+    ui.IgnoreColor->blockSignals(true);
+    ui.ColorButton->blockSignals(true);
+    ui.HorizontalClothCount->blockSignals(true);
+    ui.VerticalClothCount->blockSignals(true);
+    ui.ClothCountLink->blockSignals(true);
+    ui.PatternScale->blockSignals(true);
+    ui.CropEnabled->blockSignals(true);
+    ui.CropReset->blockSignals(true);
+    ui.UseFractionals->blockSignals(true);
 
-    m_originalSize = QSize(m_originalImage.columns(), m_originalImage.rows());
-    QString caption = i18n("Import Image - Image Size %1 x %2 pixels", m_originalSize.width(), m_originalSize.height());
-    setWindowTitle(caption);
+    ui.FlossScheme->addItems(SchemeManager::schemes());
+    ui.CropReset->setIcon(QIcon::fromTheme(QStringLiteral("edit-undo")));
 
     resetImportParameters();
-
-    m_useFractionals = ui.UseFractionals->isChecked();
-    m_ignoreColor = ui.IgnoreColor->isChecked();
-
     createImageMap();
     renderPixmap();
+
+    // unblock signals now the dialog is setup
+    ui.FlossScheme->blockSignals(false);
+    ui.UseMaximumColors->blockSignals(false);
+    ui.MaximumColors->blockSignals(false);
+    ui.IgnoreColor->blockSignals(false);
+    ui.ColorButton->blockSignals(false);
+    ui.HorizontalClothCount->blockSignals(false);
+    ui.VerticalClothCount->blockSignals(false);
+    ui.ClothCountLink->blockSignals(false);
+    ui.PatternScale->blockSignals(false);
+    ui.CropEnabled->blockSignals(false);
+    ui.CropReset->blockSignals(false);
+    ui.UseFractionals->blockSignals(false);
+    connect(ui.ImagePreview, &ScaledPixmapLabel::imageCropped, this, &ImportImageDlg::imageCropped);
+}
+
+
+void ImportImageDlg::updateWindowTitle()
+{
+    QString caption = i18n("Import Image - Image Size %1 x %2 pixels", m_crop.width(), m_crop.height());
+    setWindowTitle(caption);
 }
 
 
@@ -78,7 +111,7 @@ Magick::Image ImportImageDlg::convertedImage() const
 
 bool ImportImageDlg::ignoreColor() const
 {
-    return m_ignoreColor;
+    return ui.IgnoreColor->isChecked();
 }
 
 
@@ -108,7 +141,13 @@ double ImportImageDlg::verticalClothCount() const
 
 bool ImportImageDlg::useFractionals() const
 {
-    return m_useFractionals;
+    return ui.UseFractionals->isChecked();
+}
+
+
+QRect ImportImageDlg::croppedArea() const
+{
+    return m_crop;
 }
 
 
@@ -139,7 +178,8 @@ void ImportImageDlg::on_FlossScheme_currentIndexChanged(const QString&)
 
 void ImportImageDlg::on_UseMaximumColors_toggled(bool checked)
 {
-    m_useMaximumColors = checked;
+    Q_UNUSED(checked);
+    
     killTimer(m_timer);
     m_timer = startTimer(500);
 }
@@ -154,10 +194,11 @@ void ImportImageDlg::on_MaximumColors_valueChanged(int)
 
 void ImportImageDlg::on_IgnoreColor_toggled(bool checked)
 {
+    Q_UNUSED(checked);
+    
     delete m_alphaSelect;
     m_alphaSelect = nullptr;
 
-    m_ignoreColor = checked;
     renderPixmap();
 }
 
@@ -165,7 +206,7 @@ void ImportImageDlg::on_IgnoreColor_toggled(bool checked)
 void ImportImageDlg::on_ColorButton_clicked(bool)
 {
     m_alphaSelect = new AlphaSelect(ui.ImagePreview);
-    connect(m_alphaSelect, SIGNAL(clicked(QPoint)), this, SLOT(selectColor(QPoint)));
+    connect(m_alphaSelect, &AlphaSelect::clicked, this, &ImportImageDlg::selectColor);
     m_alphaSelect->show();
 }
 
@@ -242,9 +283,47 @@ void ImportImageDlg::on_PatternScale_valueChanged(int)
 }
 
 
+void ImportImageDlg::on_CropEnabled_toggled(bool checked)
+{
+    ui.ImagePreview->setCropping(checked);
+    if (!checked) {
+        on_CropReset_clicked(true);
+    }
+}
+
+
+void ImportImageDlg::on_CropReset_clicked(bool checked)
+{
+    Q_UNUSED(checked);
+    
+    m_convertedImage = m_originalImage;
+    m_crop = QRect(0, 0, m_originalImage.columns(), m_originalImage.rows());
+    updateWindowTitle();
+
+    renderPixmap();
+}
+
+
+void ImportImageDlg::imageCropped(const QRectF &rectF)
+{
+    // rectF is new crop rectangle relative to m_convertedImage size
+    // scale rect from m_convertedImage size to m_originalSize
+    // m_original size may be cropped from m_originalImage, but is not scaled.
+    // add new crop to original one.
+    double scaleFactor = (double)m_originalSize.width() / (double)m_convertedImage.columns();
+    QRect scaledCrop = QRect(scaleFactor*rectF.left(), scaleFactor*rectF.top(), scaleFactor*rectF.width(), scaleFactor*rectF.height());
+    m_crop = QRect(m_crop.left()+scaledCrop.left(), m_crop.top()+scaledCrop.top(), scaledCrop.width(), scaledCrop.height());
+    
+    updateWindowTitle();
+    
+    renderPixmap();
+}
+
+
 void ImportImageDlg::on_UseFractionals_toggled(bool checked)
 {
-    m_useFractionals = checked;
+    Q_UNUSED(checked);
+    
     killTimer(m_timer);
     m_timer = startTimer(500);
 }
@@ -253,10 +332,17 @@ void ImportImageDlg::on_UseFractionals_toggled(bool checked)
 void ImportImageDlg::calculateSizes()
 {
     m_convertedImage = m_originalImage;
-    m_preferredSize = m_originalSize * ui.PatternScale->value() / 100;
+    
+    if (m_crop.isValid()) {
+        m_convertedImage.chop(Magick::Geometry(m_crop.left(),m_crop.top()));
+        m_convertedImage.crop(Magick::Geometry(m_crop.width(),m_crop.height()));
+        m_originalSize = QSize(m_convertedImage.columns(), m_convertedImage.rows());
+    }
+    
+    m_preferredSize = m_originalSize * ui.PatternScale->value() / 100;    
     QSize imageSize = m_preferredSize;
 
-    if (m_useFractionals) {
+    if (ui.UseFractionals->isChecked()) {
         imageSize *= 2;
     }
 
@@ -305,9 +391,21 @@ void ImportImageDlg::renderPixmap()
     QProgressDialog progress(i18n("Rendering preview"), i18n("Cancel"), 0, pixelCount, this);
     progress.setWindowModality(Qt::WindowModal);
 
+/*
+ * ImageMagick prior to V7 used matte (opacity) to determine if an image has transparency.
+ * 0.0 for transparent to 1.0 for opaque
+ * 
+ * ImageMagick V7 now uses alpha (transparency).
+ * 1.0 for transparent to 0.0 for opaque
+ * 
+ * Access to pixels has changed too, V7 can use pixelColor to access the color of a particular
+ * pixel, but although this was available in V6, it doesn't appear to produce the same result
+ * and has resulted in black images when importing.
+ */
 #if MagickLibVersion < 0x700
     bool hasTransparency = m_convertedImage.matte();
     double transparent = 1.0;
+    const Magick::PixelPacket *pixels = m_convertedImage.getConstPixels(0, 0, width, height);
 #else
     bool hasTransparency = m_convertedImage.alpha();
     double transparent = 0.0;
@@ -322,12 +420,16 @@ void ImportImageDlg::renderPixmap()
         }
 
         for (int dx = 0 ; dx < width ; dx++) {
+#if MagickLibVersion < 0x700
+            Magick::ColorRGB rgb = Magick::Color(*pixels++);
+#else
             Magick::ColorRGB rgb = m_convertedImage.pixelColor(dx, dy);
+#endif
 
             if (hasTransparency && (rgb.alpha() == transparent)) {
                 //ignore this pixel as it is transparent
             } else {
-                if (!(m_ignoreColor && rgb == m_ignoreColorValue)) {
+                if (!(ui.IgnoreColor->isChecked() && rgb == m_ignoreColorValue)) {
                     QColor color((int)(255*rgb.red()), (int)(255*rgb.green()), (int)(255*rgb.blue()));
                     painter.setPen(QPen(color));
                     painter.drawPoint(dx, dy);
@@ -351,9 +453,9 @@ void ImportImageDlg::timerEvent(QTimerEvent*)
 
 void ImportImageDlg::pickColor()
 {
-    if (m_ignoreColor) {
+    if (ui.IgnoreColor->isChecked()) {
         m_alphaSelect = new AlphaSelect(ui.ImagePreview);
-        connect(m_alphaSelect, SIGNAL(clicked(QPoint)), this, SLOT(selectColor(QPoint)));
+        connect(m_alphaSelect, &AlphaSelect::clicked, this, &ImportImageDlg::selectColor);
         m_alphaSelect->show();
     } else {
         delete m_alphaSelect;
@@ -407,8 +509,8 @@ void ImportImageDlg::on_DialogButtonBox_helpRequested()
 void ImportImageDlg::on_DialogButtonBox_clicked(QAbstractButton *button)
 {
     if (ui.DialogButtonBox->button(QDialogButtonBox::Reset) == button) {
-        // Reset values
         m_convertedImage = m_originalImage;
+        resetImportParameters();
         renderPixmap();
     }
 }
@@ -448,7 +550,7 @@ void ImportImageDlg::resetImportParameters()
     ui.ClothCountLink->setIcon(ui.ClothCountLink->isChecked() ? QIcon::fromTheme(QStringLiteral("object-locked")) : QIcon::fromTheme(QStringLiteral("object-unlocked")));
 
     m_preferredSize = QSize(Configuration::document_Width(), Configuration::document_Height());
-
+    
     Configuration::EnumDocument_UnitsFormat::type preferredSizeUnits = Configuration::document_UnitsFormat();
     
     switch (preferredSizeUnits) {
@@ -493,7 +595,7 @@ void ImportImageDlg::resetImportParameters()
     int scaledWidth = m_preferredSize.width() * 100 / m_originalSize.width();
     int scaledHeight = m_preferredSize.height() * 100 / m_originalSize.height();
     int scale = std::min(scaledWidth, scaledHeight);
-
+    
     QString scheme = Configuration::palette_DefaultScheme();
 
     if (SchemeManager::scheme(scheme) == nullptr) {
@@ -503,6 +605,7 @@ void ImportImageDlg::resetImportParameters()
     ui.FlossScheme->setCurrentItem(scheme);
     ui.PatternScale->setValue(scale);
     ui.UseMaximumColors->setChecked(Configuration::import_UseMaximumColors());
+    ui.MaximumColors->setEnabled(ui.UseMaximumColors->isChecked());
     ui.MaximumColors->setValue(Configuration::import_MaximumColors());
     ui.MaximumColors->setMaximum(SymbolManager::library(Configuration::palette_DefaultSymbolLibrary())->indexes().count());
     ui.MaximumColors->setToolTip(QString(i18n("Colors limited to %1 due to the number of symbols available", ui.MaximumColors->maximum())));
