@@ -285,7 +285,7 @@ void PaletteManagerDlg::on_NewFloss_clicked(bool)
 
         if (floss) {
             QListWidgetItem *listWidgetItem = new QListWidgetItem;
-            listWidgetItem->setText(QString::fromLatin1("%1 %2").arg(floss->name()).arg(floss->description()));
+            listWidgetItem->setText(QString::fromLatin1("%1 %2").arg(floss->name(), floss->description()));
             listWidgetItem->setData(Qt::DecorationRole, QColor(floss->color()));
             listWidgetItem->setData(Qt::UserRole, QString(floss->name()));
 
@@ -411,7 +411,7 @@ void PaletteManagerDlg::fillLists()
 
     foreach (const Floss * floss, m_scheme->flosses()) {
         QListWidgetItem *listWidgetItem = new QListWidgetItem;
-        listWidgetItem->setText(QString::fromLatin1("%1 %2").arg(floss->name()).arg(floss->description()));
+        listWidgetItem->setText(QString::fromLatin1("%1 %2").arg(floss->name(), floss->description()));
         listWidgetItem->setData(Qt::DecorationRole, QColor(floss->color()));
         listWidgetItem->setData(Qt::UserRole, QString(floss->name()));
 
